var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// index.ts
var index_exports = {};
__export(index_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(index_exports);
var import_client_iot = require("@aws-sdk/client-iot");

// util/iot.ts
var getCertIdFromARN = (arn) => {
  return arn.split("/")[1];
};

// adapters/iot.ts
var iotAdaptor = (iot) => {
  return {
    createThing: async (thingRequest) => {
      return iot.createThing(thingRequest);
    },
    createKeysAndCertificates: async () => {
      return iot.createKeysAndCertificate({
        setAsActive: true
      });
    },
    createPolicy: async (thingName) => {
      return iot.createPolicy({
        policyName: thingName,
        policyDocument: policyDoc
      });
    },
    attachPrincipalPolicy: async (props) => {
      await iot.attachPrincipalPolicy(props);
    },
    attachThingPrincipal: async (props) => {
      return iot.attachThingPrincipal(props);
    },
    listThingPrincipals: async (thingName) => {
      return iot.listThingPrincipals({
        thingName
      });
    },
    detachPrincipalPolicy: async (props) => {
      await iot.detachPrincipalPolicy(props);
    },
    detachThingPrincipal: async (props) => {
      return iot.detachThingPrincipal(props);
    },
    updateCertificateToInactive: async (certArn) => {
      await iot.updateCertificate({
        certificateId: getCertIdFromARN(certArn),
        newStatus: "INACTIVE"
      });
    },
    deleteCertificate: async (certArn) => {
      await iot.deleteCertificate({
        certificateId: getCertIdFromARN(certArn)
      });
    },
    deletePolicy: async (policyName) => {
      await iot.deletePolicy({
        policyName
      });
    },
    deleteThing: async (thingName) => {
      await iot.deleteThing({
        thingName
      });
    }
  };
};
var policyDoc = `{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Effect": "Allow",
      "Action": [
        "iot:Publish",
        "iot:Subscribe",
        "iot:Connect",
        "iot:Receive"
      ],
      "Resource": [
        "*"
      ]
    },
    {
      "Effect": "Allow",
      "Action": [
        "iot:GetThingShadow",
        "iot:UpdateThingShadow",
        "iot:DeleteThingShadow"
      ],
      "Resource": [
        "*"
      ]
    }
  ]
}`;

// adapters/thing.ts
var thingAdaptor = (iotAdaptor2) => {
  return {
    create: async (thingName) => {
      const { thingArn } = await iotAdaptor2.createThing({
        thingName
      });
      console.info(`Thing created with ARN: ${thingArn}`);
      const { certificateId, certificateArn, certificatePem, keyPair } = await iotAdaptor2.createKeysAndCertificates();
      const { PrivateKey } = keyPair;
      const { policyArn } = await iotAdaptor2.createPolicy(thingName);
      console.info(`Policy created with ARN: ${policyArn}`);
      await iotAdaptor2.attachPrincipalPolicy({
        policyName: thingName,
        principal: certificateArn
      });
      console.info("Policy attached to certificate");
      await iotAdaptor2.attachThingPrincipal({
        principal: certificateArn,
        thingName
      });
      console.info("Certificate attached to thing");
      return {
        certId: certificateId,
        certPem: certificatePem,
        privKey: PrivateKey,
        thingArn
      };
    },
    delete: async (thingName) => {
      const { principals } = await iotAdaptor2.listThingPrincipals(thingName);
      for await (const certificateArn of principals) {
        await iotAdaptor2.detachPrincipalPolicy({
          policyName: thingName,
          principal: certificateArn
        });
        console.info(`Policy detached from certificate for ${thingName}`);
        await iotAdaptor2.detachThingPrincipal({
          principal: certificateArn,
          thingName
        });
        console.info(`Certificate detached from thing for ${certificateArn}`);
        await iotAdaptor2.updateCertificateToInactive(certificateArn);
        console.info(`Certificate marked as inactive for ${certificateArn}`);
        await iotAdaptor2.deleteCertificate(certificateArn);
        console.info(`Certificate deleted from thing for ${certificateArn}`);
        await iotAdaptor2.deleteThing(thingName);
        console.info(`Thing deleted with name: ${thingName}`);
      }
      await iotAdaptor2.deletePolicy(thingName);
      console.info(`Policy deleted: ${thingName}`);
    }
  };
};

// index.ts
var thingHandler = thingAdaptor(iotAdaptor(new import_client_iot.IoT()));
var handler = async (event) => {
  const { RequestType, LogicalResourceId, RequestId, StackId } = event;
  try {
    const thingName = event.ResourceProperties.ThingName;
    if (RequestType === "Create") {
      const { thingArn, certId, certPem, privKey } = await thingHandler.create(thingName);
      return {
        Status: "SUCCESS",
        PhysicalResourceId: thingArn,
        LogicalResourceId,
        RequestId,
        StackId,
        Data: {
          thingArn,
          certId,
          certPem,
          privKey
        }
      };
    } else if (event.RequestType === "Delete") {
      await thingHandler.delete(thingName);
      return {
        Status: "SUCCESS",
        PhysicalResourceId: event.PhysicalResourceId,
        LogicalResourceId,
        RequestId,
        StackId
      };
    } else if (event.RequestType === "Update") {
      return {
        Status: "SUCCESS",
        PhysicalResourceId: event.PhysicalResourceId,
        LogicalResourceId,
        RequestId,
        StackId
      };
    } else {
      throw new Error("Received invalid request type");
    }
  } catch (err) {
    const Reason = err.message;
    return {
      Status: "FAILED",
      Reason,
      RequestId,
      StackId,
      LogicalResourceId,
      // @ts-ignore
      PhysicalResourceId: event.PhysicalResourceId || LogicalResourceId
    };
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
